# adcc: Seamlessly connect your program to ADC
[![Documentation](https://img.shields.io/badge/doc-latest-blue.svg)](https://adc-connect.org)

`adcc` (**ADC connect**) is a `python`-based framework to connect to arbitrary programs
for running calculations based on the algebraic-diagrammatic construction
approach (ADC) on top of their self-consistent field (SCF) reference.
For more details and installation instructions
[see the `adcc` documentation](https://adc-connect.org).

## Licence note
The `adcc` source code contained in this repository is released
under the [GNU Lesser General Public License v3 (LGPLv3)](LICENSE).
This license does, however, not apply to the binary
`adccore.so` file distributed inside the folder `/adcc/lib/` of
the release tarball. For its licensing terms,
see [LICENSE_adccore](LICENSE_adccore).
